==> 0.0.23.tar.gz: lib/src/blocs/story_list_bloc.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/repository/story.dart';

///
/// Events
///
abstract class StoryListEvent {}

class StoryListRefreshEvent extends StoryListEvent {}

abstract class StoryListState {}

class StoryListIdleState extends StoryListState {}

class StoryListLoadingState extends StoryListState {}

class StoryListLoadedState extends StoryListState {
  final Map<String, List<Story>> stories;

  StoryListLoadedState(this.stories);
}

class StoryListErrorState extends StoryListState {
  final String error;

  StoryListErrorState(this.error);
}

class StoryListBloc extends Bloc<StoryListEvent, StoryListState> {
  final StoryRepository storyRepository;
  StoryListBloc(this.storyRepository) : super(StoryListIdleState());

  @override
  Stream<StoryListState> mapEventToState(StoryListEvent event) async* {
    if (event is StoryListRefreshEvent) {
      yield StoryListLoadingState();
      AppResponse<List<Story>> storiesResponse =
          await storyRepository.getStories();

      if (storiesResponse.isSuccess) {
        Map<String, List<Story>> stories = {};
        storiesResponse.data.forEach((element) {
          if (stories.containsKey(element.user?.id)) {
            stories.putIfAbsent(element.user?.id, () => []);
          } else {
            stories["${element.user?.id}"].add(element);
          }
        });
        yield StoryListLoadedState(stories);
      } else {
        yield StoryListErrorState(storiesResponse.error);
      }
    }
  }
}

==> 0.0.24.tar.gz: lib/src/blocs/story_list_bloc.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/repository/story.dart';

///
/// Events
///
abstract class StoryListEvent {}

class StoryListRefreshEvent extends StoryListEvent {}

abstract class StoryListState {}

class StoryListIdleState extends StoryListState {}

class StoryListLoadingState extends StoryListState {}

class StoryListLoadedState extends StoryListState {
  final Map<String, List<Story>> stories;

  StoryListLoadedState(this.stories);
}

class StoryListErrorState extends StoryListState {
  final String error;

  StoryListErrorState(this.error);
}

class StoryListBloc extends Bloc<StoryListEvent, StoryListState> {
  final StoryRepository storyRepository;
  StoryListBloc(this.storyRepository) : super(StoryListIdleState());

  @override
  Stream<StoryListState> mapEventToState(StoryListEvent event) async* {
    if (event is StoryListRefreshEvent) {
      yield StoryListLoadingState();
      AppResponse<List<Story>> storiesResponse =
          await storyRepository.getStories();

      if (storiesResponse.isSuccess) {
        Map<String, List<Story>> stories = {};
        storiesResponse.data.forEach((element) {
          if (!stories.containsKey(element.user?.id)) {
            stories.putIfAbsent(element.user?.id, () => []);
          } else {
            stories["${element.user?.id}"].add(element);
          }
        });
        yield StoryListLoadedState(stories);
      } else {
        yield StoryListErrorState(storiesResponse.error);
      }
    }
  }
}
